@@ -2,7 +2,7 @@
 #
 # (c) 2002 - 2016, Arthur Corliss <corliss@digitalmages.com>,
 #
-# $Id: lib/Parse/PlainConfig.pm, 3.02 2016/05/26 13:04:45 acorliss Exp $
+# $Id: lib/Parse/PlainConfig.pm, 3.03 2016/08/09 16:11:12 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -23,7 +23,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-($VERSION) = ( q$Revision: 3.02 $ =~ /(\d+(?:\.(\d+))+)/sm );
+($VERSION) = ( q$Revision: 3.03 $ =~ /(\d+(?:\.(\d+))+)/sm );
 
 use Class::EHierarchy qw(:all);
 use Parse::PlainConfig::Constants qw(:all);
@@ -573,8 +573,8 @@ sub parse {
         # See if we have property block
         if ( _snarfBlock( @lines, $prop, $value, $settings ) ) {
 
-            # Parse the block
-            $rv = _snarfProp( $obj, $prop, $value );
+            # Parse the block (but preserve earlier errors)
+            $rv = 0 unless _snarfProp( $obj, $prop, $value );
 
         } else {
 
@@ -742,7 +742,7 @@ Parse::PlainConfig - Configuration file class
 
 =head1 VERSION
 
-$Id: lib/Parse/PlainConfig.pm, 3.02 2016/05/26 13:04:45 acorliss Exp $
+$Id: lib/Parse/PlainConfig.pm, 3.03 2016/08/09 16:11:12 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -1120,7 +1120,7 @@ specific prototype preamble.
 
     $errStr = $config->error;
 
-Returns the last error that occured.  Note that this isn't reset between
+Returns the last error that occurred.  Note that this isn't reset between
 method invocations.
 
 =head1 DEPENDENCIES
